@@ -257,7 +257,14 @@ def test_remote_name(repo_with_remote):
         assert repo.remote_name == remote_name
 
 
-def test_remote_name_too_many_remotes(tmpdir, repo_with_remote):
+def test_all_remote_names(tmpdir, repo_with_remote):
+    repo, remote_name = repo_with_remote
+    assert repo.all_remote_names == [remote_name]
+    _create_remote_repo(tmpdir, repo, "upstream2", "remote_path2")
+    assert repo.all_remote_names == [remote_name, "upstream2"]
+
+
+def test_remote_name_many_remotes(tmpdir, repo_with_remote):
     repo, _ = repo_with_remote
     _create_remote_repo(tmpdir, repo, "upstream2", "remote_path2")
 
@@ -265,8 +272,7 @@ def test_remote_name_too_many_remotes(tmpdir, repo_with_remote):
         assert repo.remote_name == "upstream2"  # Branch is set to an upstream one
         repo.run("branch", "--unset-upstream")
 
-    with pytest.raises(RuntimeError):
-        repo.remote_name
+    assert repo.remote_name == "upstream"
 
 
 def test_remote_name_default_and_origin(tmpdir, repo_with_remote):
@@ -282,7 +288,7 @@ def test_remote_name_default_and_origin(tmpdir, repo_with_remote):
 
 def test_default_branch_guess(repo):
     if repo.tool == "git":
-        assert repo.default_branch == "master"
+        assert repo.default_branch == "refs/heads/master"
     else:
         assert repo.default_branch == "default"
 
@@ -290,7 +296,7 @@ def test_default_branch_guess(repo):
 def test_default_branch_remote_query(repo_with_remote):
     repo, _ = repo_with_remote
     if repo.tool == "git":
-        assert repo.default_branch == "master"
+        assert repo.default_branch == "upstream/master"
     else:
         assert repo.default_branch == "default"
 
@@ -301,7 +307,7 @@ def test_default_branch_cloned_metadata(tmpdir, repo):
         command = ("git", "clone", repo.path, clone_repo_path)
         subprocess.check_output(command, cwd=tmpdir)
         cloned_repo = get_repository(clone_repo_path)
-        assert cloned_repo.default_branch == "master"
+        assert cloned_repo.default_branch == "origin/master"
 
 
 def assert_files(actual, expected):
